@@ -29,7 +29,7 @@ from idds.orm import (transforms as orm_transforms,
 
 
 @transactional_session
-def add_transform(request_id, workload_id, transform_type, transform_tag=None, priority=0,
+def add_transform(request_id, workload_id, transform_type, transform_tag=None, priority=0, name=None,
                   status=TransformStatus.New, substatus=TransformStatus.New, locking=TransformLocking.Idle,
                   new_poll_period=1, update_poll_period=10, retries=0, expired_at=None, transform_metadata=None,
                   new_retries=0, update_retries=0, max_new_retries=3, max_update_retries=0,
@@ -56,7 +56,7 @@ def add_transform(request_id, workload_id, transform_type, transform_tag=None, p
     transform_id = orm_transforms.add_transform(request_id=request_id, workload_id=workload_id,
                                                 transform_type=transform_type, transform_tag=transform_tag,
                                                 priority=priority, status=status, substatus=substatus,
-                                                locking=locking, retries=retries,
+                                                locking=locking, retries=retries, name=name,
                                                 new_poll_period=new_poll_period,
                                                 update_poll_period=update_poll_period,
                                                 new_retries=new_retries, update_retries=update_retries,
