@@ -1,3 +1,4 @@
+import time                       # noqa F401
 from datetime import datetime     # noqa F401
 
 from idds.common.utils import json_dumps, setup_logging                 # noqa F401
@@ -27,5 +28,8 @@ transform_id = 26788   # 3028, 3029
 # ret = core_catalog.update_contents_from_others_by_dep_id(request_id=request_id, transform_id=transform_id)
 # print(ret)
 
-ret = core_catalog.get_updated_transforms_by_content_status(request_id=3350)
-print(ret)
+for req_id in [3350, 3407, 3414, 3420]:
+    start = time.time()
+    ret = core_catalog.get_updated_transforms_by_content_status(request_id=req_id)
+    print('request_id: %s, time: %s' % (req_id, time.time() - start))
+    print(ret)
